summaryrefslogtreecommitdiffstats
path: root/webkit/database/database_tracker.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/database/database_tracker.h')
-rw-r--r--webkit/database/database_tracker.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/webkit/database/database_tracker.h b/webkit/database/database_tracker.h
index e4c8183..4976a91 100644
--- a/webkit/database/database_tracker.h
+++ b/webkit/database/database_tracker.h
@@ -145,10 +145,12 @@ class DatabaseTracker
net::CompletionCallback* callback);
// Delete any databases that have been touched since the cutoff date that's
// supplied. Returns net::OK on success, net::FAILED if not all databases
// could be deleted, and net::ERR_IO_PENDING and |callback| is invoked upon
// completion, if non-NULL.
int DeleteDataModifiedSince(const base::Time& cutoff,
+ const std::vector<string16>& protected_origins,
net::CompletionCallback* callback);
// Delete all databases that belong to the given origin. Returns net::OK on
@@ -145,10 +145,12 @@ class DatabaseTracker
net::CompletionCallback* callback);
// Delete any databases that have been touched since the cutoff date that's
- // supplied. Returns net::OK on success, net::FAILED if not all databases
- // could be deleted, and net::ERR_IO_PENDING and |callback| is invoked upon
- // completion, if non-NULL.
+ // supplied, omitting any that match IDs within |protected_origins|.
+ // Returns net::OK on success, net::FAILED if not all databases could be
+ // deleted, and net::ERR_IO_PENDING and |callback| is invoked upon completion,
+ // if non-NULL.
int DeleteDataModifiedSince(const base::Time& cutoff,